OC.L10N.register(
    "settings",
    {
    "Private" : "Privado",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Visível apenas a pessoas cujo acesso é realizado através de número de telefone, na app Talk em dispositivos móveis.",
    "Local" : "Local",
    "Only visible to people on this instance and guests" : "Visível apenas a pessoas nesta instância e a convidados",
    "Federated" : "Federada",
    "Only synchronize to trusted servers" : "Apenas sincronizar em servidores confiáveis",
    "Published" : "Publicado",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar a servidor confiável e global e lista de endereço público",
    "Verify" : "Verificar",
    "Verifying …" : "A verificar...",
    "Unable to change password" : "Não é possível alterar a sua palavra-passe ",
    "Very weak password" : "Palavra-passe muito fraca",
    "Weak password" : "Palavra-passe fraca",
    "So-so password" : "Palavra-passe aceitável",
    "Good password" : "Palavra-passe boa",
    "Strong password" : "Palavra-passe forte",
    "Groups" : "Grupos",
    "Group list is empty" : "Lista de grupo vazia",
    "Unable to retrieve the group list" : "Não foi possível recolher a lista de grupo",
    "An administrator added you to group {group}" : "Um administrador adicionou-o ao grupo {group}",
    "An administrator added {user} to group {group}" : "Um administrador adicionou {user} ao grupo {group}",
    "{actor} removed you from group {group}" : "{actor} removeu-o do grupo {group}",
    "You removed {user} from group {group}" : "Removeu {user} do grupo {group}",
    "{actor} changed your password" : "{actor} alterou a sua senha",
    "You changed your password" : "Você alterou a sua senha",
    "Your password was reset by an administrator" : "A sua senha foi alterada por um administrador",
    "Your password was reset" : "A sua password foi redefinida",
    "{actor} changed your email address" : "{actor} alterou o seu endereço de e-mail",
    "You changed your email address" : "Você alterou o seu endereço de e-mail",
    "Your email address was changed by an administrator" : "O seu endereço de e-mail foi alterado por um administrador",
    "Security" : "Segurança",
    "You successfully logged in using two-factor authentication (%1$s)" : "Autenticado com sucesso utilizando autenticação de dois factores (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Tentativa falhada de autenticação utilizando dois factores (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>password</strong> ou <strong>email</strong> foram modificados",
    "Settings" : "Configurações",
    "Could not remove app." : "Não foi possível remover a aplicação",
    "Could not update app." : "Não foi possível atualizar a aplicação",
    "Wrong password" : "Palavra-passe errada",
    "Unable to change personal password" : "Não foi possível mudar a palavra-passe pessoal",
    "Saved" : "Guardado",
    "Unable to change password. Password too long." : "Não foi possível mudar a palavra-passe. Palavra-passe demasiado longa.",
    "Authentication error" : "Erro na autenticação",
    "Wrong admin recovery password. Please check the password and try again." : "Palavra-passe de recuperação do administrador errada. Por favor, verifique a palavra-passe e tente novamente.",
    "Administrator documentation" : "Documentação de Administrador.",
    "User documentation" : "Documentação de Utilizador",
    "Invalid SMTP password." : "Senha de SMTP inválida.",
    "Email setting test" : "Teste definições de email",
    "Well done, %s!" : "Muito bem, %s!",
    "If you received this email, the email configuration seems to be correct." : "Se recebeu este email, a configuração do serviço de email deverá estar correcta.",
    "Email could not be sent. Check your mail server log" : "O email não pode ser enviado. Por favor verifique os logs do seu servidor de e-mail.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ocorreu um problema ao enviar o e-mail. Por favor verifique as suas definições. (Erro: %s)",
    "Invalid account" : "Conta inválida",
    "Invalid mail address" : "Endereço de correio eletrónico inválido",
    "Settings saved" : "Definições guardadas",
    "Unable to change full name" : "Não foi possível alterar o seu nome completo",
    "Unable to change email address" : "Não foi possível alterar o seu endereço de e-mail",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Por forma a validar a sua conta de Twitter, por favor publique o seguinte Twitter ( garanta que a publicação não contém quebras de linha):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Por forma de validar o Website, por favor publique o conteúdo seguinte na sua raiz em 'well-known/CloudIdVerificationCode.txt' (garanta que o texto completo se encontra numa única linha):",
    "%1$s changed your password on %2$s." : "%1$s modificou a sua senha em %2$s.",
    "Your password on %s was changed." : "A sua senha para %s foi modificada.",
    "Your password on %s was reset by an administrator." : "A sua senha para  %s foi redefinida pelo administrador.",
    "Password for %1$s changed on %2$s" : "A senha para %1$s foi modificada em %2$s",
    "Password changed for %s" : "Senha modificada para %s",
    "If you did not request this, please contact an administrator." : "Se não requereu isto por favor contacte um administrador.",
    "Your email address on %s was changed." : "O endereço de e-mail me %s foi modificado.",
    "Your email address on %s was changed by an administrator." : "O seu endereço de email em %s foi modificado por um administrador.",
    "Email address for %1$s changed on %2$s" : "Endereço de e-mail para %1$s modificado em %2$s",
    "Email address changed for %s" : "Endereço de e-mail modificado para %s",
    "The new email address is %s" : "O novo endereço de e-mail é %s",
    "Your %s account was created" : "A tua conta %s foi criada",
    "Welcome aboard" : "Bem-vindo a bordo",
    "Welcome aboard %s" : "Bem-vindo a bordo %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Bem-vindo à conta %s, aqui pode adicionar, proteger e partilhar os seus dados.",
    "Set your password" : "Escolher senha",
    "Go to %s" : "Ir para %s",
    "Install Client" : "Instalar cliente",
    "Apps" : "Apps",
    "Personal" : "Pessoal",
    "Administration" : "Administração",
    "Users" : "Utilizadores",
    "Additional settings" : "Definições adicionais",
    "Administration privileges" : "Privilégios de administração",
    "Overview" : "Visão Geral",
    "Basic settings" : "Definições básicas",
    "Sharing" : "Partilha",
    "Availability" : "Disponibilidade",
    "Calendar" : "Calendário",
    "Personal info" : "Informação pessoal",
    "Mobile & desktop" : "Móvel e área de trabalho",
    "Email server" : "Servidor de Correio Eletrónico",
    "Security & setup warnings" : "Avisos de configuração e segurança",
    "Background jobs" : "Tarefas de segundo plano",
    "Unlimited" : "Ilimitado",
    "Verifying" : "A verificar",
    "Disabled" : "Desactivado",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "A função PHP \"set_time_limit\" não está disponível. Isto pode resultar na paragem de scripts a meio da execução, corrompendo a instalação. A activação desta função é altamente recomendada.",
    "Supported" : "Suportado",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "O seu PHP não suporta FreeType, podendo resultar em fotos de perfil e interface de definições corrompidos. ",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "O PHP não parece estar bem configurado para consultar variáveis do ambiente do sistema. O teste com getenv(\"PATH\") apenas devolveu uma resposta em branco.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "A configuração Só-de-Leitura foi ativada. Isto evita definir algumas configurações através da interface da Web. Além disso, o ficheiro precisa de ser definido gravável manualmente para cada atualização.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "A sua base de dados não tem o nível de isolamento da transacção \"READ COMMITTED\" activado. Isto pode causar problemas quando várias acções são executadas em paralelo.",
    "Profile information" : "Informação de perfil",
    "Nextcloud settings" : "Definições Nextcloud",
    "None" : "Nenhum",
    "Allow apps to use the Share API" : "Permitir que os utilizadores usem a API de partilha",
    "Allow resharing" : "Permitir repartilha",
    "Allow sharing with groups" : "Permitir partilha com grupos.",
    "Restrict users to only share with users in their groups" : "Restringe os utilizadores só a partilhar com utilizadores do seu grupo",
    "Allow public uploads" : "Permitir Envios Públicos",
    "Always ask for a password" : "Pedir sempre a senha",
    "Enforce password protection" : "Forçar proteção por palavra-passe",
    "Enforce expiration date" : "Forçar a data de expiração",
    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto será exibido na página de carregamento de ligações públicas quando a lista de ficheiros estiver oculta. ",
    "Limit to groups" : "Limitado a grupos",
    "Save changes" : "Guardar alterações",
    "Remove" : "Remover",
    "Disable" : "Desativar",
    "Featured" : "Destacado",
    "All apps are up-to-date." : "Todas as aplicações estão atualizadas",
    "Name" : "Nome",
    "Version" : "Versão",
    "Level" : "Nível",
    "Actions" : "Acções",
    "Results from other categories" : "Resultados de outras categorias",
    "No apps found for your version" : "Nenhuma aplicação encontrada para a sua versão",
    "Disable all" : "Desativar todos",
    "_Update_::_Update all_" : ["Atualizar","Atualizar todos","Atualizar todos"],
    "Loading" : "A carregar",
    "Description" : "Descrição",
    "Details" : "Detalhes",
    "All" : "Todos",
    "No results" : "Sem resultados",
    "Update to {version}" : "Actualizar para {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão mínima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta app não tem a versão máxima do Nextcloud atribuída. Isto será um erro no futuro.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicação não pode ser instalada porque as seguintes dependências não podem ser realizadas:",
    "Categories" : "Categorias",
    "Resources" : "Recursos",
    "Documentation" : "Documentação",
    "Report a bug" : "Reportar um erro",
    "Request feature" : "Pedir funcionalidade",
    "Ask questions or discuss" : "Perguntar ou discutir",
    "Rate" : "Classificar",
    "View in store" : "Ver na loja",
    "Visit website" : "Visitar o website",
    "Admin documentation" : "Documentação do Administrador",
    "Developer documentation" : "Documentação de Programador",
    "Changelog" : "Registo de alterações",
    "Device settings" : "Definições de dispositivo",
    "Allow filesystem access" : "Permitir acesso ao sistema de ficheiros",
    "Rename" : "Renomear",
    "Revoke" : "Revogar",
    "Wipe device" : "Apagar dispositivo",
    "Google Chrome for Android" : "Google Chrome para Android",
    "This session" : "Esta sessão",
    "Device" : "Dispositivo",
    "Last activity" : "Última atividade",
    "Devices & sessions" : "Sessões e dispositivos",
    "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, desktop e clientes móveis estão actualmente autenticados na sua conta.",
    "App name" : "Nome da App",
    "Create new app password" : "Criar nova palavra-passe de aplicação",
    "Error while creating device token" : "Erro durante a criação do token do dispositivo",
    "Login" : "Iniciar Sessão",
    "Password" : "Palavra-passe",
    "Profile" : "Perfil",
    "Enable" : "Ativar",
    "Server-side encryption" : "Atualizar App",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A cifra do lado do servidor possibilita cifrar os ficheiros que serão enviados para este servidor. Isto implica um impacto no desempenho e só deverá ser activo quando necessário.",
    "Enable server-side encryption" : "Ativar encriptação do lado do servidor",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Uma vez ativada a encriptação, todos os ficheiros carregados para o servidor a partir deste ponto serão encriptados pelo servidor. Só será possível desativar a encriptação numa data mais tarde se o módulo de encriptação ativo suportar essa função, assim como todas as pré-condições (e.g. definir chave de recuperação) sejam cumpridas.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A cifra por si só não garante a segurança do sistema. Por favor consulte a documentação para mais detalhes sobre a aplicação de cifra e os casos de uso suportados.",
    "Be aware that encryption always increases the file size." : "Tenha em conta que a encriptação aumenta sempre o tamanho do ficheiro.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "É sempre bom criar cópias de segurança regulares dos seus dados, em caso de encriptação tenha a certeza de que faz cópia das chaves de encriptação em conjunto com os seus dados.",
    "This is the final warning: Do you really want to enable encryption?" : "Este é o aviso final: quer mesmo ativar a encriptação?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nenhum módulo de encriptação carregador, por favor ative um módulo de encriptação no menu das aplicações.",
    "Select default encryption module:" : "Selecionar o módulo de encriptação predefinido:",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Submit" : "Submeter",
    "Current password" : "Palavra-passe atual",
    "New password" : "Nova palavra-passe",
    "Change password" : "Alterar palavra-passe",
    "Your profile picture" : "Imagem de perfil",
    "Upload profile picture" : "Atualização de imagem de perfil",
    "Choose profile picture from Files" : "Escolher a imagem de perfil em Ficheiros",
    "Remove profile picture" : "Remover imagem de perfil",
    "Picture provided by original account" : "Imagem fornecida pela conta original",
    "Set as profile picture" : "Definir como imagem de perfil",
    "Choose your profile picture" : "Escolher imagem de perfil",
    "Please select a valid png or jpg file" : "Escolha ficheiro png ou jpg válido",
    "Error setting profile picture" : "Erro a definir imagem de perfil",
    "Error cropping profile picture" : "Erro a cortar imagem de perfil",
    "Error saving profile picture" : "Erro a guardar imagem de perfil",
    "Error removing profile picture" : "Erro a remover imagem de perfil",
    "Your biography" : "Biografia",
    "You are a member of the following groups:" : "Membro dos seguintes grupos:",
    "Your full name" : "Nome completo",
    "Email options" : "Opções de correio eletrónico",
    "Remove primary email" : "Remoção de correio eletrónico principal",
    "Delete email" : "Apagar correio eletrónico",
    "Unset as primary email" : "Remove atribuição de correio eletrónico como principal",
    "No email address set" : "Nenhum endereço de email estabelecido",
    "Help translate" : "Ajude a traduzir",
    "Your phone number" : "O seu número de telefone",
    "Add" : "Adicionar",
    "Create" : "Criar",
    "Change" : "Mudar",
    "Delete" : "Apagar",
    "Reshare" : "Partilhar novamente",
    "Display name" : "Nome de apresentação",
    "Email" : "Email",
    "Quota" : "Quota",
    "Language" : "Idioma",
    "Avatar" : "Avatar",
    "Username" : "Nome de utilizador",
    "Group admin for" : "Administrador de grupo para",
    "User backend" : "Backend do utilizador",
    "Storage location" : "Localização do armazenamento",
    "Last login" : "Último início de sessão",
    "{size} used" : "{size} utilizado",
    "Done" : "Concluído",
    "Edit" : "Editar",
    "Visibility" : "Visibilidade",
    "Show last login" : "Mostrar último login",
    "Send email" : "Enviar email",
    "Default quota" : "Quota padrão",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador pode afinar o comportamento de partilha. Por favor veja a documentação para mais informação.",
    "Admins" : "Administrador",
    "Group name" : "Nome do grupo",
    "Sending…" : "A enviar...",
    "Email sent" : "Mensagem de correio eletrónico enviada",
    "Location" : "Localização",
    "Profile picture" : "Foto do perfil",
    "About" : "Sobre",
    "Full name" : "Nome completo",
    "Headline" : "Título ",
    "Organisation" : "Organização",
    "Phone number" : "Número de telefone",
    "Role" : "Função",
    "Website" : "Website",
    "Your apps" : "As suas apps",
    "Disabled apps" : "Apps desativadas",
    "Updates" : "Actualizações",
    "App bundles" : "Pacotes de apps",
    "Hide" : "Ocultar",
    "Download and enable" : "Transferir e ativar",
    "Never" : "Nunca",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "A app foi activada mas necessita ser actualizada. Irá ser redireccionado para a página de actualização em 5 segundos.",
    "Do you really want to wipe your data from this device?" : "Tem a certeza que deseja apagar os dados deste dispositivo?",
    "Confirm wipe" : "Confirmação de limpeza",
    "Forum" : "Fórum",
    "Legal notice" : "Informação legal",
    "Privacy policy" : "Política de privacidade",
    "SSL" : "SSL",
    "Open documentation" : "Abrir documentação",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "É importante configurar este servidor para ser possível enviar emails, possibilitando enviar notificações bem como possibilitar a recuperação de senhas.",
    "Send mode" : "Modo de Envio",
    "Encryption" : "Encriptação",
    "From address" : "Do endereço",
    "Server address" : "Endereço do Servidor",
    "Port" : "Porta",
    "Authentication" : "Autenticação",
    "Authentication required" : "Autenticação necessária",
    "Credentials" : "Credenciais",
    "SMTP Password" : "Palavra-passe SMTP",
    "Save" : "Guardar",
    "All checks passed." : "Todas as verificações passaram.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desenvolvido pela [communityopen]Comunidade Nextcloud[linkclose]. O [githubcode]código fonte[/linkclose] está licenciado sob [licenseopen]AGPL[linkclose].",
    "Like our Facebook page" : "Deixe um Gosto na nossa página do Facebook",
    "Follow us on Twitter" : "Siga-nos no Twitter",
    "Check out our blog" : "Veja o nosso blog",
    "Subscribe to our newsletter" : "Subscreva as nossas notícias",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Este lançamento comunitário do Nextcloud não é compatível e as notificações instantâneas não estão disponíveis.",
    "No user supplied" : "Nenhum utilizador especificado",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor introduza uma senha administrativa de recuperação ou todos os dados de utilizador serão perdidos.",
    "Federated Cloud Sharing" : "Federated Cloud Sharing",
    "Invalid user" : "Utilizador inválido",
    "Your username is: %s" : "O seu utilizador é: %s",
    "Enable all" : "Ativar todas",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Microsoft Edge",
    "Firefox" : "Mozilla Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Sync client - {os}" : "Sincronizar cliente - {so}",
    "Error while deleting the token" : "Erro durante a eliminação do token",
    "Use the credentials below to configure your app or device." : "Use as credenciais abaixo para configurar a sua app ou dispositivo.",
    "For security reasons this password will only be shown once." : "Por motivos de segurança a sua password só será mostrada uma vez.",
    "Copied!" : "Copiado!",
    "Copy" : "Copiar",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para esta execução precisa da extensão PHP POSIX. Veja {iniciodaligação}documentação PHP{fimdaligação} para mais mais detalhes.",
    "Your profile information" : "Informação de perfil",
    "Your email address" : "O seu endereço de email",
    "Add group" : "Adicionar grupo",
    "Active users" : "Utilizadores activos",
    "Show user backend" : "Mostrar interface do utilizador",
    "Send email to new user" : "Enviar email ao novo utilizador",
    "Not saved" : "Não guardado",
    "Twitter" : "Twitter",
    "SMTP Username" : "Nome de utilizador SMTP",
    "Set default expiration date" : "Especificar a data padrão de expiração",
    "Exclude groups from sharing" : "Excluir grupos das partilhas",
    "These groups will still be able to receive shares, but not to initiate them." : "Estes grupos poderão receber partilhas, mas não poderão iniciá-las."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
